<?php
/* ----------------------------
Plugin Name: Disk Player
Plugin URI: http://srvalle.com/disk-audio-player
Description: Disk Audio Player is a WordPress plugin to display html5 audio player in your website with unlimited color options and playlists. Main features: HTML5, responsive, retina ready, works on desktop/tablet/phone and playlist with scrollbar.
Version: 2.13
Author: Sergio Valle
Author URI: http://srvalle.com/
------------------------------ */



if ( ! class_exists( 'Disk_Player' ) ) :

class Disk_Player {

	function __construct() {

		define( 'DISK_PLAYER_URL', plugins_url().'/'.basename( dirname( __FILE__ ) ) );

        // plugin activation
		register_activation_hook( __FILE__, array( &$this, 'disk_player_activate' ) );

        // register post type
		add_action( 'init', array( &$this, 'disk_player_register_post_type') );
        add_filter('admin_head', array( &$this, 'disk_player_hide_permalinks' ) );


		// add disk player image sizes
		add_image_size( 'disk-player-thumb', 80, 80, true );

		// print CSS style
		add_action('wp_print_styles', array( &$this, 'disk_player_print_styles' ) );

		// enqueue scripts
		$dplayer_settings = get_option('dplayer_settings');
		$open_scripts_hook = isset($dplayer_settings['open_scripts_hook']) ? $dplayer_settings['open_scripts_hook'] : 'wp_enqueue_scripts';
		add_action($open_scripts_hook, array( &$this, 'disk_player_enqueue_script') );

		// add shortcode		
		add_shortcode('disk_player', array( &$this, 'disk_player_shortcode') );

		// Add shortcode support for widgets
    	add_filter('widget_text', 'do_shortcode');


        if ( is_admin() ) {
            
            // init custom meta box
            add_action( 'init', array( &$this, 'disk_player_initialize_cmb_meta_boxes' ) );

            // add menu page
            add_action( 'admin_menu', array( &$this, 'disk_player_add_menu' ) );
			
			// action hook to register option settings
            add_action( 'admin_init', array( &$this, 'disk_player_register_settings' ) );

            // add cols in admin
            add_action( 'admin_init', array( &$this, 'disk_player_add_custom_cols' ) );

            // duplicate post diskplayer
            add_action( 'admin_init', array( &$this, 'disk_player_duplicate_post' ) );
			
			//count songs
			add_action('wp_ajax_action_count_songs', array( &$this, 'disk_player_my_action' ) );
			add_action('wp_ajax_nopriv_action_count_songs', array( &$this, 'disk_player_my_action' ) );
        }
	}

	// --------------------------------------------------------------------------

	function disk_player_activate() {
		//if still not there / important to keep the recorded data after updates
        if( !get_option( "dplayer_settings" ) ) {
            $dplayer_settings_arr = array(
                "open_scripts_hook" => "wp_enqueue_scripts",
				"open_scripts_local" => "footer"
            );

            //save default option values
            update_option('dplayer_settings', $dplayer_settings_arr);
        }

        // ----------

		//register taxonomies/post types here
        $this->disk_player_register_post_type();
        flush_rewrite_rules();
	}

    function disk_player_hide_permalinks() {
        global $post;
        if( !is_object($post) ) return;

        if ($post->post_type == 'diskplayer') {
            echo '<style type="text/css">#edit-slug-box,#view-post-btn,#post-preview,.updated p a{display: none;}</style>';
			
			echo '<style type="text/css">.edit-post-header-toolbar__left, .block-editor-post-preview__dropdown, .interface-pinned-items, .interface-more-menu-dropdown, .block-editor-inserter, .block-editor-block-list__layout, .post-publish-panel__postpublish-post-address-container, .post-publish-panel__postpublish-buttons { display: none; } .wp-block-post-title { margin-left: 20px !important; } .components-snackbar-list__notice-container { width: 300px; } .components-snackbar__content { font-size: 24px; } .components-snackbar__content .components-snackbar__action { display: none; } .editor-post-publish-button { font-size: 16px; } </style>';
        }
    }

	// --------------------------------------------------------------------------


	//Print CSS
	function disk_player_print_styles() {
		wp_enqueue_style( 'jplayer-dplayer', DISK_PLAYER_URL . '/css/disk-player-dark.css', array(), '1.0', 'all' );
	}

	// --------------------------------------------------------------------------

	//Enqueue scripts
	function disk_player_enqueue_script() {
		$dplayer_settings = get_option('dplayer_settings');
		$open_scripts_local = $dplayer_settings['open_scripts_local'] === 'header' ? false : true;

		wp_enqueue_script( 'jquery' );

        wp_enqueue_script( 'disk-player-jplayer', DISK_PLAYER_URL . '/js/jquery.jplayer.min.js', 'jquery', '2.9.2', $open_scripts_local );
		
		wp_register_script( 'disk-player-jplayer-playlist', DISK_PLAYER_URL . '/js/jplayer.playlist.js', 'jquery', '2.9.2', $open_scripts_local );
		
		wp_enqueue_script( 'disk-player-tinyscrollbar', DISK_PLAYER_URL . '/js/jquery.tinyscrollbar.js', 'jquery', '2.5.0', $open_scripts_local );

		$dp_dir = array( 'disk_player_dir' => DISK_PLAYER_URL );
        wp_localize_script( 'disk-player-jplayer-playlist', 'object_diskplayer', $dp_dir );
		wp_enqueue_script( 'disk-player-jplayer-playlist' );
		
		wp_register_script( 'disk-player-count-song-views', DISK_PLAYER_URL . '/js/disk_player_count_song_views.js', 'jquery', '1.0', $open_scripts_local );
		$arr_data = array( 'ajax_url' => admin_url('admin-ajax.php'), 'test_prop' => 1234 );
		wp_localize_script( 'disk-player-count-song-views', 'ajax_object', $arr_data);
		wp_enqueue_script( 'disk-player-count-song-views' );
	}
	
	//song views
	function disk_player_my_action() {
		
		//-----------------------------------------------
		//estudo esta no arquivo disk-player-metabox.php
		//-----------------------------------------------
		
		//get access to the database
		global $wpdb;

		$player_id = intval( $_POST['player_id'] );
		$song_indice = intval( $_POST['song_indice'] );
		$song_title = $_POST['song_title'];


		//get song views
		$songviews = get_post_meta($player_id, '_dplayer_rep_', false);
	
		//loop
		$id_song_tmp = 0;
		foreach ($songviews[0] as $value) {	
			if ( $value['_dplayer_track_title'] == $song_title ) {	
				$getsongviews = $songviews[0][$id_song_tmp]['_dplayer_song_views'];
				$addsongviews = $getsongviews + 1;
				break;
			} else {
				$id_song_tmp = $id_song_tmp + 1;
			}
		}

		
		//update song views
		$songviews = get_post_meta($player_id, '_dplayer_rep_', true);
		//[0] é o indice da song
		$songviews[$id_song_tmp]['_dplayer_song_views'] = $addsongviews;
		update_post_meta($player_id, '_dplayer_rep_', $songviews );

		echo $addsongviews;

		//this is required to terminate immediately and return a proper response
		wp_die();
	}


	// --------------------------------------------------------------------------

	//shortcode
	function disk_player_shortcode($atts, $content = null) {

		extract(shortcode_atts(array(
			'id' => 1,
			'tracks' => ''
		), $atts));

		global $post;
		$querydplayer = new WP_Query( array ('p' => absint($id), 'post_type' => 'diskplayer') );

		if ( $querydplayer->have_posts() ) : while ( $querydplayer->have_posts() ) : $querydplayer->the_post();

			// get settings
			$default_image_poster = get_post_meta($post->ID,'_dplayer_cmb_default_image_poster',true);		
			$reverse_order = get_post_meta($post->ID,'_dplayer_cmb_reverse_order',true == 'on' ) ? 'true' : 'false';
			$hide_scrollbar_if_mobile = get_post_meta($post->ID,'_dplayer_cmb_hide_scrollbar_if_mobile',true == 'on' ) ? 'true' : 'false';
            $display_numbers = get_post_meta($post->ID,'_dplayer_cmb_display_numbers',true == 'on' ) ? 'true' : 'false';
			$display_howmany_items = trim( get_post_meta($post->ID,'_dplayer_cmb_display_howmany_items',true) );
			if ($display_howmany_items == '') $display_howmany_items = 3;
			$track_height = trim( get_post_meta($post->ID,'_dplayer_cmb_track_height',true) );
            $autoplay = get_post_meta($post->ID,'_dplayer_cmb_autoplay',true == 'on' ) ? 'true' : 'false';
            $disable_header = get_post_meta($post->ID,'_dplayer_cmb_disable_header',true == 'on' ) ? 'true' : 'false';
			$disable_scrollbar = get_post_meta($post->ID,'_dplayer_cmb_disable_scrollbar',true == 'on' ) ? 'true' : 'false';
            $disable_playlist = get_post_meta($post->ID,'_dplayer_cmb_disable_playlist',true == 'on' ) ? 'true' : 'false';
            $enable_skins = get_post_meta($post->ID,'_dplayer_cmb_enable_skins',true == 'on' ) ? 'true' : 'false';
            $skin = get_post_meta($post->ID,'_dplayer_cmb_skin',true);
			$stop_next_song = get_post_meta($post->ID,'_dplayer_cmb_stop_next_song',true == 'on' ) ? 'true' : 'false';

            // colors/opacity
            $title_icons_color = get_post_meta($post->ID,'_dplayer_cmb_title_icons_color',true);
			$title_icons_color_onhover = get_post_meta($post->ID,'_dplayer_cmb_title_icons_color_onhover',true);
			$font_color = get_post_meta($post->ID,'_dplayer_cmb_font_color',true);
			$sliders_color = get_post_meta($post->ID,'_dplayer_cmb_sliders_color',true);
            $container_border_color = get_post_meta($post->ID,'_dplayer_cmb_container_border_color',true);
            $header_color = get_post_meta($post->ID,'_dplayer_cmb_header_color',true);
            $header_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_header_color_opacity',true);
			$header_color_opacity = $header_color_opacity / 100;
            $interface_color = get_post_meta($post->ID,'_dplayer_cmb_interface_color',true);
            $interface_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_interface_color_opacity',true);
			$interface_color_opacity = $interface_color_opacity / 100;
            $interface_border_color = get_post_meta($post->ID,'_dplayer_cmb_interface_border_color',true);
            $playlist_item_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color',true);
            $playlist_item_color_opacity = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color_opacity',true);
			$playlist_item_color_opacity = $playlist_item_color_opacity / 100;
            $playlist_item_color_onhover = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_color_onhover',true);
            $playlist_item_border_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_item_border_color',true);
            $playlist_current_item_color = get_post_meta($post->ID,'_dplayer_cmb_playlist_current_item_color',true);
            $scrollbar_color = get_post_meta($post->ID,'_dplayer_cmb_scrollbar_color',true);
            $buttons_control_color = get_post_meta($post->ID,'_dplayer_cmb_buttons_control_color',true);
            $toggles_color = get_post_meta($post->ID,'_dplayer_cmb_toggles_color',true);
            $seek_volume_bar = get_post_meta($post->ID,'_dplayer_cmb_seek_volume_bar',true);
            $progress_bar = get_post_meta($post->ID,'_dplayer_cmb_progress_bar',true);
            $other_elem_opacity = get_post_meta($post->ID,'_dplayer_cmb_other_elements_opacity',true);
			$other_elem_opacity = $other_elem_opacity / 100;
            $background_image_player = get_post_meta($post->ID,'_dplayer_cmb_background_image_player',true);
			$background_image_repeat = get_post_meta($post->ID,'_dplayer_cmb_background_image_repeat',true);
			$custom_style = get_post_meta($post->ID,'_dplayer_cmb_custom_style',true);
			$custom_javascript = get_post_meta($post->ID,'_dplayer_cmb_custom_javascript',true);


			//NEW METABOX DATA

			$new_tracks = get_post_meta($post->ID,'_dplayer_rep_',true);
			if ( !empty( $new_tracks ) ) {
				//get new metabox data
				$trackGroups = $new_tracks;
				$new_data = true;
			}

			//Add tracks filter
			/*
			if ( !empty($tracks) ) {
				$tmpTrackGroups = $trackGroups;
				unset($trackGroups);
				$trackGroups = array();
				$tracks = explode(",", $tracks);

				for ( $i = 0; $i < count($tmpTrackGroups); $i++ ) {
					$track_id = $i+1;
					
					if ( in_array($track_id, $tracks) ) {
						array_push( $trackGroups, $tmpTrackGroups[$i] );
					}
				}
				unset($tmpTrackGroups);
			}
			*/


			if ($reverse_order === 'true') {
				//Return an array in the reverse order
            	$trackGroups = array_reverse($trackGroups);
			}

			$totalTracks = count($trackGroups);

		endwhile; else:
			echo '<div>Disk Player Not Found With ID ' . $id . '</div>';
			return;
		endif;
		wp_reset_postdata();

		//enqueue skin

        if ($enable_skins === 'true') {
            if ($skin == 'light') {
                wp_enqueue_style( 'jplayer-dplayer-light', DISK_PLAYER_URL . '/css/disk-player-light.css', array(), '1.0', 'all' );
            } elseif ($skin == 'dark') {
                wp_enqueue_style( 'jplayer-dplayer-dark', DISK_PLAYER_URL . '/css/disk-player-dark.css', array(), '1.0', 'all' );
            
            } elseif ($skin == 'grunge') {
                wp_enqueue_style( 'jplayer-dplayer-grunge', DISK_PLAYER_URL . '/css/disk-player-grunge.css', array(), '1.0', 'all' );
                
            } elseif ($skin == 'stone') {
                wp_enqueue_style( 'jplayer-dplayer-stone', DISK_PLAYER_URL . '/css/disk-player-stone.css', array(), '1.0', 'all' );
			
			} elseif ($skin == 'onebutton') {
                wp_enqueue_style( 'jplayer-dplayer-onebutton', DISK_PLAYER_URL . '/css/disk-player-one-button.css', array(), '1.0', 'all' );
			}
        } else {
            $skin = "dark";
        }
		
		//custom javascript
		if ( $custom_javascript !== '' ) {
			$custom_javascript = str_replace("\n", "", $custom_javascript);
			$custom_javascript = str_replace("  ", "", $custom_javascript);
			echo "<script type='text/javascript'>" .  $custom_javascript  . "</script>";
        }

		//custom style
        if ( $custom_style !== '' ) {
            $custom_style = str_replace("\n", "", $custom_style); //remove new lines
            $custom_style = str_replace("\r", "", $custom_style); //remove carriage returns
			$dap_custom_style = $custom_style;
        } else {
			$dap_custom_style = '';
        }

        $header_color_RGB = disk_player_hex2rgb($header_color);
        $header_color_RGBA = "rgba($header_color_RGB,$header_color_opacity)";

        $interface_color_RGB = disk_player_hex2rgb($interface_color);
        $interface_color_RGBA = "rgba($interface_color_RGB,$interface_color_opacity)";

        $plist_color_RGB = disk_player_hex2rgb($playlist_item_color);
        $plist_color_RGBA = "rgba($plist_color_RGB,$playlist_item_color_opacity)";

        $plist_cur_color_RGB = disk_player_hex2rgb($playlist_current_item_color);
        $plist_cur_color_RGBA = "rgba($plist_cur_color_RGB,$playlist_item_color_opacity)";

        $plist_onhover_RGB = disk_player_hex2rgb($playlist_item_color_onhover);
        $plist_onhover_RGBA = "rgba($plist_onhover_RGB,$playlist_item_color_opacity)";

        $btns_control_RGB = disk_player_hex2rgb($buttons_control_color);
        $btns_control_RGBA = "rgba($btns_control_RGB,$other_elem_opacity)";

        $toggles_color_RGB = disk_player_hex2rgb($toggles_color);
        $toggles_color_RGBA = "rgba($toggles_color_RGB,$other_elem_opacity)";

        $scrollbar_RGB = disk_player_hex2rgb($scrollbar_color);
        $scrollbar_RGBA = "rgba($scrollbar_RGB,$other_elem_opacity)";


		$output = '';
		$dp_container = '#disk-player-container_' . $id;
		$output .= '<div style="height:0;display:none;"><style type="text/css">';

			//add custom style
			$output .= $dap_custom_style;

            //general settings
            if ($disable_playlist === 'true' || $skin === 'onebutton') {
                $output .= $dp_container . ' div.dap-playlist {';
                $output .= 'display:none !important;';
                $output .= '}';
            } else {
                $output .= $dp_container . ' div.dap-playlist {';
                $output .= 'display:block !important;';
                $output .= '}';
            }

			//track li height		
			if ($track_height === 'auto') {
                $output .= $dp_container . ' div.dap-playlist li {';
                $output .= 'height:auto;';
                $output .= '}';
            }

            if ($disable_header === 'true') {
                $output .= $dp_container . ' .dap-jplayer {';
                $output .= 'height:0 !important;';
                $output .= 'opacity:0 !important;';
                $output .= '}';

                $output .= $dp_container . ' .dap-jplayer img {';
                $output .= 'display:none !important;';
                $output .= 'height:0 !important;';
                $output .= 'opacity:0 !important;';
                $output .= '}';

                $output .= $dp_container . ' .dplayer-current-track {';
                $output .= 'display:none !important;';
                $output .= '}';
				
				$output .= $dp_container . ' .dap-interface {';
                $output .= 'border:none !important;';
                $output .= '}';
            }

            //colors settings

            if ($enable_skins === 'false') {

                $output .= $dp_container . ' {';
				$output .= 'border:1px solid ' . $container_border_color . ';';

				if ($new_data) {
					if (isset($background_image_player['url'])) {
						$output .= 'background-image: url(' . $background_image_player['url'] . ');';
					}
				}

                $output .= 'background-repeat: ' . $background_image_repeat . ';';

                $output .= '}';

                $output .= $dp_container . ' div.dap-jplayer {';
                $output .= 'background-color:' . $header_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface {';
                $output .= 'background-color:' . $interface_color_RGBA . ' !important;';
                $output .= 'border-top-color:' . $interface_border_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-playlist li {';
                $output .= 'background-color:' . $plist_color_RGBA . ' !important;';
                $output .= 'border-top:1px solid ' . $playlist_item_border_color . ';';
                $output .= '}';
                $output .= $dp_container . ' div.dap-playlist li:hover, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist li.dap-playlist-current:hover {';
                $output .= 'background-color:' . $plist_onhover_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-type-playlist div.dap-playlist li.dap-playlist-current {';
                $output .= 'background:' . $plist_cur_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' .dplayer-scrollbar .scrollbar {';
                $output .= 'background:' . $scrollbar_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' .dap-play, ' . $dp_container . ' .dap-pause, ' . $dp_container . ' .dap-previous, ' . $dp_container . ' .dap-next, ' . $dp_container . ' .dap-stop {';
                $output .= 'background-color:' . $btns_control_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' ul.dap-toggles {';
                $output .= 'background:' . $toggles_color_RGBA . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-seek-bar, ' . $dp_container . ' div.dap-volume-bar  {';
                $output .= 'background:' . $seek_volume_bar . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface a, ' . $dp_container . ' div.dap-interface li a, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist a {';
                $output .= 'color:' . $title_icons_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-interface a:hover, ' . $dp_container . ' div.dap-type-playlist div.dap-playlist a:hover {';
                $output .= 'color:' . $title_icons_color_onhover . ' !important;';
                $output .= '}';

                $output .= $dp_container . ', ' . $dp_container . ' span.dap-artist, ' . $dp_container . ' span.dap-numbers {';
                $output .= 'color:' . $font_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-volume-bar-value, ' .  $dp_container . ' div.dap-play-bar, ' .  $dp_container . ' .dplayer-scrollbar .thumb {';
                $output .= 'background:' . $sliders_color . ' !important;';
                $output .= '}';

                $output .= $dp_container . ' div.dap-progress {';
                $output .= 'background:' . $progress_bar . ' !important;';
                $output .= '}';
            }
		$output .= '</style></div>';

		$output .='<div style="display:inline;"><script type="text/javascript">
				(function($) {
				"use strict";
				$(document).ready(function() {
					//add custom style
					//$("head").append("' . $dap_custom_style . '");
					var myPlaylist = new jPlayerPlaylist({
						jPlayer: "#jquery_jplayer_' . $id . '",
						cssSelectorAncestor: "#jp_container_' . $id . '"
					}, [';
						//loop all tracks
						for ( $i=0; $i < $totalTracks; $i++) {
							if ($new_data) {
								$output .= '{';
								if ( isset($trackGroups[$i]['_dplayer_track_title']) && $trackGroups[$i]['_dplayer_track_title'] != '' ) {
									if ($display_numbers === 'true') {
										if ($i < 9) {
											$number = '0' . ($i + 1) . ': ';
										} else {
											$number = $i + 1 . ': ';
										}
									} else {
										$number = '';
									}
									$trackGroups[$i]['_dplayer_track_title'] = str_replace('"', '\"', $trackGroups[$i]['_dplayer_track_title']);
									////$output .= 'title:"' . '<span class=\"dap-numbers\">' . $number . '</span>' . $trackGroups[$i]['_dplayer_track_title'] . '",';
									$output .= 'title:"' . '<span class=\"dap-numbers\">' . $number . '</span><span class=\"dap-title\">' . $trackGroups[$i]['_dplayer_track_title'] . '</span>",';
								}
								if ( isset($trackGroups[$i]['_dplayer_artist']) && $trackGroups[$i]['_dplayer_artist'] != '' ) {
									$trackGroups[$i]['_dplayer_artist'] = str_replace('"', '\"', $trackGroups[$i]['_dplayer_artist']);
									$output .= 'artist:"' . $trackGroups[$i]['_dplayer_artist'] . '",';
								}
								if ( isset($trackGroups[$i]['_dplayer_buy_url']) && $trackGroups[$i]['_dplayer_buy_url'] != '' ) {
									$trackGroups[$i]['_dplayer_buy_text'] = isset($trackGroups[$i]['_dplayer_buy_text']) ? $trackGroups[$i]['_dplayer_buy_text'] : "";
									$output .= 'cart:["' . esc_url($trackGroups[$i]['_dplayer_buy_url']) . '","' . $trackGroups[$i]['_dplayer_buy_text'] . '","' . $i . '" ],';
								}
								if ( isset($trackGroups[$i]['_dplayer_download_url']) && $trackGroups[$i]['_dplayer_download_url'] != '' ) {
									$trackGroups[$i]['_dplayer_download_text'] = isset($trackGroups[$i]['_dplayer_download_text']) ? $trackGroups[$i]['_dplayer_download_text'] : "";
									$trackGroups[$i]['_dplayer_force_download'] = (isset($trackGroups[$i]['_dplayer_force_download']) && $trackGroups[$i]['_dplayer_force_download'] == "on") ? "true" : "false";
									$output .= 'download:["' . esc_url($trackGroups[$i]['_dplayer_download_url']) . '","' . $trackGroups[$i]['_dplayer_download_text'] . '","' . $trackGroups[$i]['_dplayer_force_download'] . '","' . $i . '" ],';
								}
								if ( isset($trackGroups[$i]['_dplayer_extra_info_url']) && $trackGroups[$i]['_dplayer_extra_info_url'] != '' ) {
									$trackGroups[$i]['_dplayer_extra_info_text'] = isset($trackGroups[$i]['_dplayer_extra_info_text']) ? $trackGroups[$i]['_dplayer_extra_info_text'] : "";
									$output .= 'extrainfo:["' . esc_url($trackGroups[$i]['_dplayer_extra_info_url']) . '","' . $trackGroups[$i]['_dplayer_extra_info_text'] . '","' . $i . '"],';
								}
								if ( isset($trackGroups[$i]['_dplayer_mp3_file_url']) && $trackGroups[$i]['_dplayer_mp3_file_url'] != '') {
									$track_url = $trackGroups[$i]['_dplayer_mp3_file_url'];
								} else {
									$track_url = $trackGroups[$i]['_dplayer_mp3_file']['url'];
								}
								$output .= 'mp3:"' . esc_url($track_url) . '",';
								$output .= 'wav:"' . esc_url($track_url) . '",';
								$output .= 'oga:"' . esc_url($track_url) . '",';
								$poster_image = ( isset($trackGroups[$i]['_dplayer_poster_image']['url']) && $trackGroups[$i]['_dplayer_poster_image']['url'] != '' ) ? $trackGroups[$i]['_dplayer_poster_image'] : $default_image_poster;
								if ( $disable_header === 'false' && $poster_image != '' ) {
									$output .= 'poster:"' . esc_url($poster_image['url']) . '"';
								}
								$output .= '},';
							}//if $new_data
						}//for
						$solutionHtmlFlash = "html, flash";
					$output .=
					'], {
						playlistOptions: {
							enableRemoveControls: false
						},

						swfPath: "' . DISK_PLAYER_URL . '/js",
						solution: "' . $solutionHtmlFlash . '", //test if the swfPath is correct ( "flash, html" )
						supplied: "mp3,m4a,oga,wav,webmv, ogv, m4v",
						wmode: "window",
						smoothPlayBar: true,
						keyEnabled: true,
						audioFullScreen: true,
						preload: "none",
						size: {
							width: "80",
							height: "110",
							cssClass: ""
						}
					});
					
					//event.ended
					$("#jquery_jplayer_' . $id . '").on($.jPlayer.event.ended, function(event) {';
					  	//optional stop the next
						if ($stop_next_song === 'true') {
							$output .= '$(this).jPlayer("stop");';
						}
					$output .= '
					});
					
					//event.play
					$("#jquery_jplayer_' . $id . '").on($.jPlayer.event.play, function(event) {

                        var current = myPlaylist.current;
						callCountViews ( $id, current );

						$("#dplayer-current-track_' . $id . ' .dplayer-title, #dplayer-current-track_' . $id . ' .dplayer-artist").empty();
						$("#dplayer-current-track_' . $id . ' .dplayer-title").prepend(myPlaylist.playlist[myPlaylist.current].title);
						$("#dplayer-current-track_' . $id . ' .dplayer-artist").prepend(myPlaylist.playlist[myPlaylist.current].artist);
					});

					//event.ready
					$("#jquery_jplayer_' . $id . '").on($.jPlayer.event.ready, function(event) {
						$("#dplayer-current-track_' . $id . ' div").empty();
						$("#dplayer-current-track_' . $id . ' .dplayer-title").append(myPlaylist.playlist[myPlaylist.current].title);
						$("#dplayer-current-track_' . $id . ' .dplayer-artist").append(myPlaylist.playlist[myPlaylist.current].artist);';

						//shuffle, repeat, autoplay -> automatic
                        if ($autoplay === 'true') {
                            $output .= '$("#jquery_jplayer_' . $id . '").jPlayer("play");';
                        }
                    $output .= '
					});
					// ----- scrollbar ---------
                    $(window).load({noncache: new Date().getTime()},function() {
						var is_mobile_js = "' . wp_is_mobile() . '";
                        setTimeout(function(){
							//se for mais que 1 track e Track Height = Auto
                        }, 2500);
                    });
					// -------------------------
                    // parent container // hide volume
                    var isTouch = "ontouchstart" in window || "onmsgesturechange" in window ? true : false;
					var $container = $( "' . $dp_container . '" );
					if ( isTouch ) { 
						$container.find(".dap-volume-bar-group").hide();
					}
					var $id = "' .  $id . '";
					$(window).on("resize", function(e) {
						var parentWidth = $container.parent().width();
						if (parentWidth < 385) {
							$container.find(".dap-volume-max, .dap-volume-bar, .dap-unmute").hide();
							$container.find(".dap-volume-max, .dap-volume-bar, .dap-unmute").css( { visibility: "hidden" } );
						} else {
							$container.find(".dap-volume-max, .dap-volume-bar, .dap-mute").show();
							$container.find(".dap-volume-max, .dap-volume-bar, .dap-mute").css( { visibility: "visible" } );
						}
					});//resize
					setTimeout(function(){ $container.trigger("resize") }, 1000);
					$container.find("p:empty").remove();
                    // -------------------------
				});//ready
				})(jQuery);
			</script></div>';
		$output .= '
			<div id="disk-player-container_' . $id . '" class="disk-player-container ' . $skin . '">

				<div id="jquery_jplayer_' . $id . '" class="dap-jplayer"></div>

				<div id="dplayer-current-track_' . $id . '" class="dplayer-current-track">
					<div class="dplayer-title"></div>
					<div class="dplayer-artist"></div>
				</div>

				<div id="jp_container_' . $id . '" class="dap-audio">
					<div class="dap-type-playlist">
						<div class="dap-gui dap-interface">
							<ul class="dap-controls">
								<li><a href="javascript:;" class="dap-previous" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-play" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-pause" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-next" tabindex="1"></a></li>
								<li><a href="javascript:;" class="dap-stop" tabindex="1"></a></li>
							</ul>
							<div class="dap-volume-bar-group">
								<a href="javascript:;" class="dap-mute" tabindex="1" title="mute"></a>
								<a href="javascript:;" class="dap-unmute" tabindex="1" title="unmute"></a>
								<div class="dap-volume-bar">
									<div class="dap-volume-bar-value"></div>
								</div>
								<a href="javascript:;" class="dap-volume-max" tabindex="1" title="max volume"></a>
							</div>
							<div class="dap-progress">
								<div class="dap-seek-bar">
									<div class="dap-play-bar"></div>
								</div>
							</div>
							<div class="dap-time-holder">
								<div class="dap-current-time"></div>
								<div class="dap-duration"></div>
							</div>
							<ul class="dap-toggles">
								<li><a href="javascript:;" class="dap-shuffle" tabindex="1" title="shuffle"></a></li>
								<li><a href="javascript:;" class="dap-shuffle-off" tabindex="1" title="shuffle off"></a></li>
								<li><a href="javascript:;" class="dap-repeat" tabindex="1" title="repeat"></a></li>
								<li><a href="javascript:;" class="dap-repeat-off" tabindex="1" title="repeat off"></a></li>
							</ul>
						</div>';

						$output .= '
						<div id="dap-playlist_' . $id . '" class="dap-playlist ' . $skin . '">';
							$output .= '
								<ul class="">';
								//add for seo issues
								for ( $i=0; $i < $totalTracks; $i++) {
									$output .= '<li>';
									if ( isset($trackGroups[$i]['_dplayer_track_title']) && $trackGroups[$i]['_dplayer_track_title'] != '' ) {
										$output .= $trackGroups[$i]['_dplayer_track_title'] . ' - ';
									}
									if ( isset($trackGroups[$i]['_dplayer_artist']) && $trackGroups[$i]['_dplayer_artist'] != '' ) {
										$output .= $trackGroups[$i]['_dplayer_artist'];
									}
									$output .= '</li>';
								}
								$output .= '</ul>
						</div>
						<div class="dap-no-solution">
							<span>Update Required</span>
							To play the media you will need to either update your browser to a recent version or update your <a href="http://get.adobe.com/flashplayer/" target="_blank">Flash plugin</a>.
						</div>
					</div>
				</div>
			</div>';
		return $output;
	}//shortcode

	// --------------------------------------------------------------------------

	// Register post type
	
	function disk_player_register_post_type() {

		$labels = array( 
			'name' => _x( 'Disk Players', 'dplayer' ),
			'singular_name' => _x( 'Disk Player', 'dplayer' ),
			'add_new' => _x( 'Add New', 'dplayer' ),
			'add_new_item' => _x( 'Add New Disk Player', 'dplayer' ),
			'all_items'  =>  _x( 'Disk Players', 'dplayer' ),
			'edit_item' => _x( 'Edit Disk Player', 'dplayer' ),
			'new_item' => _x( 'New Disk Player', 'dplayer' ),
			'view_item' => _x( 'View Disk Player', 'dplayer' ),
			'search_items' => _x( 'Search Disk Players', 'dplayer' ),
			'not_found' => _x( 'No disk player found', 'dplayer' ),
			'not_found_in_trash' => _x( 'No disk players found in Trash', 'dplayer' ),
			'parent_item_colon' => '',
			'menu_name' => _x( 'Disk Player', 'dplayer' ),
		);

		$args = array(
			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'query_var' => false,
			'rewrite' => array( 'slug' => esc_attr__('diskplayer', 'dplayer') ),
			'capability_type' => 'post',
			'has_archive' => false,
			'hierarchical' => false,
			'menu_position' => 5.3,		
			'show_in_rest' => true,
			'supports' => array( 'title', 'editor' ),
			'exclude_from_search' => true,
			'description' => 'Present your soundtracks',
			'menu_icon' => DISK_PLAYER_URL . '/img/disk_player_menu_icon.png',
		);

		register_post_type( 'diskplayer', $args );
	}
	
	// --------------------------------------------------------------------------


    // Add MetaBox

	function disk_player_initialize_cmb_meta_boxes() {
		//My-Meta-Box framework
        require_once( 'includes/metabox-n/meta-box-class/my-meta-box-class.php' );
        require_once( 'includes/metabox-n/disk-player-metabox.php' );
	}

	// Add cols post type
	function disk_player_add_custom_cols() {

		function disk_player_add_thumb_column($cols) { 
			$cols['thumbnail'] = esc_attr__('Thumbnail');
			return $cols;
		}
		function disk_player_add_thumb_value($column_name, $post_id) {

			// avoids duplicate thumbnails
			global $typenow;

			if ($typenow == 'diskplayer' && 'thumbnail' == $column_name) {
				$thumbnail_id = get_post_meta($post_id,'_dplayer_cmb_default_image_poster', true);

				if ($thumbnail_id) {
                    $thumb = wp_get_attachment_image( $thumbnail_id['id'], array(60, 60), false );
				}

				if ( isset($thumb) && $thumb ) {
					echo $thumb;
				} else {
					echo esc_attr__('None','dplayer');
				}
			}
		}


		function disk_player_add_shortcode_column($cols) { 
			$cols['shortcode_name'] = esc_attr__('Shortcode');
			return $cols;
		}
		function disk_player_getpostid($column_name, $post_ID) {
			global $post;
			if ($column_name == 'shortcode_name') {
				// show content of 'shortcode_name' column
				$shorcode_value = '[disk_player id="' . $post_ID . '"]';
				echo "<input type='text' name='disk_player_shortcode' value='$shorcode_value' />";
				echo "<br><small style='color:#888;'>Copy and paste this shortcode on a page, post or widget Text.</small>";
			}
		}

		function disk_player_edit_columns($columns) {
			$columns = array(
				"cb" => "<input type=\"checkbox\" />",
				"title" => esc_attr__('Title', 'dplayer'), 
				"thumbnail" => esc_attr__('Thumbnail', 'dplayer'),
				"shortcode_name" => esc_attr__('Shortcode', 'dplayer'), 
				"author" => esc_attr__('Author', 'dplayer'), 
				"date" => esc_attr__('Date', 'dplayer')
			);
			return $columns;
		}

		//add thumbnail to diskplayer post type in admin
		add_filter( 'manage_diskplayer_posts_columns', 'disk_player_add_thumb_column' );
		add_action( 'manage_posts_custom_column', 'disk_player_add_thumb_value', 10, 2 );
		add_filter( 'manage_diskplayer_posts_columns', 'disk_player_add_shortcode_column' );
		add_action('manage_diskplayer_posts_custom_column', 'disk_player_getpostid', 10, 2);
		add_filter("manage_edit-diskplayer_columns", "disk_player_edit_columns"); //order columns

	}//disk_player_add_custom_cols


	// --------------------------------------------------------------------------


	// Add options sub-menu
	
	function disk_player_add_menu() {
		//help
		add_submenu_page( 'edit.php?post_type=diskplayer', esc_attr__( 'Help', 'dplayer' ), esc_attr__( 'Help', 'dplayer' ), 'administrator', 'dplayer-help', array( &$this, 'disk_player_help_page' ) );
		
		//settings
		add_submenu_page( 'edit.php?post_type=diskplayer', esc_attr__( 'Settings', 'dplayer' ), esc_attr__( 'Settings', 'dplayer' ), 'administrator', 'dplayer-settings-fields', array( &$this, 'disk_player_settings_page' ) );
	}
	
	function disk_player_register_settings() {
        //register Array of settings
        register_setting( 'dplayer-settings-fields', 'dplayer_settings' );
    }

	// --------------------------------------------------------------------------

	// help page
	
	function disk_player_help_page() {
        require_once( 'includes/disk_player_help.php' );
	}
	
	// --------------------------------------------------------------------------

	// settings page
	
	function disk_player_settings_page() {
        require_once( 'includes/disk_player_settings.php' );
	}


    // --------------------------------------------------------------------------

    // Function duplicate post diskplayer

    function disk_player_duplicate_post(){

        //Function creates post duplicate as a draft and redirects then to the diskplayer list

        function disk_player_duplicate_post_as_draft(){
            global $wpdb;
            if (! ( isset( $_GET['post']) || isset( $_POST['post'])  || ( isset($_REQUEST['action']) && 'disk_player_duplicate_post_as_draft' == $_REQUEST['action'] ) ) ) {
                wp_die('No post to duplicate has been supplied!');
            }

            //get the original post id
            $post_id = (isset($_GET['post']) ? $_GET['post'] : $_POST['post']);

            //and all the original post data then
            $post = get_post( $post_id );

            //if you don't want current user to be the new post author,
            //then change next couple of lines to this: $new_post_author = $post->post_author;
            $current_user = wp_get_current_user();
            $new_post_author = $current_user->ID;

            //if post data exists, create the post duplicate
            if (isset( $post ) && $post != null) {

                //new post data array
                $args = array(
                    'comment_status' => $post->comment_status,
                    'ping_status'    => $post->ping_status,
                    'post_author'    => $new_post_author,
                    'post_content'   => $post->post_content,
                    'post_excerpt'   => $post->post_excerpt,
                    'post_name'      => $post->post_name,
                    'post_parent'    => $post->post_parent,
                    'post_password'  => $post->post_password,
                    'post_status'    => 'draft',
                    'post_title'     => $post->post_title . ' Copy',
                    'post_type'      => $post->post_type,
                    'to_ping'        => $post->to_ping,
                    'menu_order'     => $post->menu_order
                );

                //insert the post by wp_insert_post() function
                $new_post_id = wp_insert_post( $args );

                //get all current post terms ad set them to the new post draft
                $taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag");
                foreach ($taxonomies as $taxonomy) {
                    $post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
                    wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
                }

                //duplicate all post meta
                $post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$post_id");
                if (count($post_meta_infos)!=0) {
                    $sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
                    foreach ($post_meta_infos as $meta_info) {
                        $meta_key = $meta_info->meta_key;
                        $meta_value = addslashes($meta_info->meta_value);
                        $sql_query_sel[]= "SELECT $new_post_id, '$meta_key', '$meta_value'";
                    }
                    $sql_query.= implode(" UNION ALL ", $sql_query_sel);
                    $wpdb->query($sql_query);
                }

                //redirect to diskplayer list
                wp_redirect( admin_url( 'edit.php?post_type=diskplayer' ) );

                exit;
            } else {
                wp_die('Post creation failed, could not find original post: ' . $post_id);
            }
        }
        add_action( 'admin_action_disk_player_duplicate_post_as_draft', 'disk_player_duplicate_post_as_draft' );


        //Add the duplicate link to action list for post_row_actions
        function disk_player_duplicate_post_link( $actions, $post ) { 
            //When using custom post type use the post_row_actions filter hook and check the post type to modify it only
            if ($post->post_type == "diskplayer") {
                if (current_user_can('edit_posts')) {
                    $actions['duplicate'] = '<a href="admin.php?action=disk_player_duplicate_post_as_draft&amp;post=' . $post->ID . '" title="Duplicate this item" rel="permalink">Duplicate</a>';
                }
            }
            return $actions;
        }
        add_filter( 'post_row_actions', 'disk_player_duplicate_post_link', 10, 2 );

    }//disk_player_duplicate_post

} // end class
endif;

$disk_player = new Disk_Player;



if( ! function_exists( 'disk_player_hex2rgb' ) ):

// Returns rgb color

function disk_player_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);

   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
}
endif;